#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Megan Riel-Mehan.
# Distributed under the terms of the Modified BSD License.


version_info = (0, 1, 4)
__version__ = ".".join(map(str, (version_info)))
