"use strict";(self.webpackChunknbsv=self.webpackChunknbsv||[]).push([[480],{4480:function(e,t,r){var n=this&&this.__createBinding||(Object.create?function(e,t,r,n){void 0===n&&(n=r);var i=Object.getOwnPropertyDescriptor(t,r);i&&!("get"in i?!t.__esModule:i.writable||i.configurable)||(i={enumerable:!0,get:function(){return t[r]}}),Object.defineProperty(e,n,i)}:function(e,t,r,n){void 0===n&&(n=r),e[n]=t[r]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),u=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var r in e)"default"!==r&&Object.prototype.hasOwnProperty.call(e,r)&&n(t,e,r);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0});const o=r(1829),a=u(r(1367)),c=r(8657),s={id:"nbsv:plugin",requires:[o.IJupyterWidgetRegistry],activate:function(e,t){t.registerWidget({name:c.MODULE_NAME,version:c.MODULE_VERSION,exports:a})},autoStart:!0};t.default=s}}]);